﻿using Microsoft.AspNetCore.Mvc;
using System;
using System.Threading.Tasks;
using System.Collections.Generic;
using System.Linq;
using Microsoft.EntityFrameworkCore;
using APICycleVDP.DB;

namespace APICycleVDP.Controllers
{
	[ApiController]
	[Route("cycles")]
	public class CyclesController(DbVdpContext context) : ControllerBase
    {
		private readonly DbVdpContext _context = context;

        [HttpPost("current")]
        public async Task<IActionResult> CurrCycles()
        {
            var result = new
            {
                currTime = DateTime.UtcNow,
                data = new List<object>()
            };

			var cycles = _context.Cycles
				.GroupBy(x => x.NumVdp)
				.Select(x => x.OrderByDescending(x => x.FactStart).FirstOrDefault());

			foreach (var cycle in cycles)
			{
				if (cycle != null)
				{
                    result.data.Add(new
                    {
						vdp = cycle.NumVdp,
						cycle = cycle.NumCycle,
						factStart = cycle.FactStart.ToUniversalTime(),
						factEnd = cycle.FactEnd.ToUniversalTime(),
						thinkEnd = cycle.ThinkEnd.ToUniversalTime()
					});
				}
			}

			return Ok(result);
        }
	}
}
