using APICycleVDP.DB;
using APICycleVDP.Services;
using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using System;

namespace APICycleVDP
{
    public class Program
    {
        public static void Main(string[] args)
        {
            var builder = WebApplication.CreateBuilder(args);
			builder.WebHost.UseKestrel();

			//Add context DB
			builder.Services.AddDbContext<DbVdpContext>(options =>
            options.UseMySql(builder.Configuration.GetConnectionString("MySql"),
                new MySqlServerVersion(new Version(8, 4, 3))));

            builder.Services.AddCors(options =>
            {
                options.AddDefaultPolicy(
                    policy =>
                    {
                        policy.AllowAnyOrigin();
                        policy.AllowAnyHeader();
                        policy.AllowAnyMethod();
                    });
            });

            builder.Services.AddControllers();

            var useGenCycles = bool.TryParse(builder.Configuration["UseGenCycles"], out bool resConfBool) && resConfBool;
            builder.Services.AddHostedService<VdpCyclesGen>();

			var useSwagger = bool.TryParse(builder.Configuration["UseSwagger"], out resConfBool) && resConfBool;
			if (useSwagger)
			{
				builder.Services.AddEndpointsApiExplorer();
				builder.Services.AddSwaggerGen();
			}

			var app = builder.Build();

			using (var scope = app.Services.CreateScope())
			{
				var dbContext = scope.ServiceProvider.GetRequiredService<DbVdpContext>();
				dbContext.Database.EnsureCreated();
			}

			if (useSwagger)
			{
				app.UseSwagger();
				app.UseSwaggerUI(options =>
				{
					options.SwaggerEndpoint("/swagger/v1/swagger.json", "v1");
					//options.RoutePrefix = string.Empty;
				});
			}

			app.UseCors();

			app.UseAuthorization();
			app.MapControllers();
			app.Run();
        }
    }
}